==> dde-control-center_5.5.88.orig.tar.xz: dde-control-center-5.5.88/translations/recovery_nl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="nl">
<context>
    <name>BackgroundWidget</name>
    <message>
        <location filename="../abrecovery/backgroundwidget.cpp" line="49"/>
        <location filename="../abrecovery/backgroundwidget.cpp" line="65"/>
        <source>Rolling back the system, please wait...</source>
        <translation>Het systeem wordt teruggerold - even geduld...</translation>
    </message>
</context>
<context>
    <name>RecoveryDialog</name>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="266"/>
        <source>Rollback failed.</source>
        <translation>Het terugrollen is mislukt.</translation>
    </message>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="271"/>
        <source>Reboot</source>
        <translation>Herstarten</translation>
    </message>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="280"/>
        <source>Are you sure you want to roll back to %1 backed up on %2?</source>
        <translation>Weet je zeker dat je wilt terugrollen naar back-up %1 van %2?</translation>
    </message>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="283"/>
        <source>Cancel and Reboot</source>
        <translation>Annuleren en herstarten</translation>
    </message>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="284"/>
        <source>Confirm</source>
        <translation>Oké</translation>
    </message>
</context>
</TS>

==> dde-control-center_5.5.149.orig.tar.xz: dde-control-center-5.5.149/translations/recovery_nl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="nl">
<context>
    <name>BackgroundWidget</name>
    <message>
        <location filename="../abrecovery/backgroundwidget.cpp" line="33"/>
        <location filename="../abrecovery/backgroundwidget.cpp" line="49"/>
        <source>Rolling back the system, please wait...</source>
        <translation>Het systeem wordt teruggerold - even geduld...</translation>
    </message>
</context>
<context>
    <name>RecoveryDialog</name>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="250"/>
        <source>Rollback failed.</source>
        <translation>Terugrollen mislukt.</translation>
    </message>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="255"/>
        <source>Reboot</source>
        <translation>Herstarten</translation>
    </message>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="264"/>
        <source>Are you sure you want to roll back to %1 backed up on %2?</source>
        <translation>Weet je zeker dat je wilt terugrollen naar back-up %1 van %2?</translation>
    </message>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="267"/>
        <source>Cancel and Reboot</source>
        <translation>Annuleren en herstarten</translation>
    </message>
    <message>
        <location filename="../abrecovery/recoverydialog.cpp" line="268"/>
        <source>Confirm</source>
        <translation>Oké</translation>
    </message>
</context>
</TS>
